import Foundation

struct UserDetail: Codable {
    var ID_Login: String
    var ID_Application: String = APP_ID
}

struct UserRoleAll: Codable {
    var ID_Login: String
    var ID_User: String
    var IsActive: String = "true"
    var ID_Application: String = APP_ID
}

struct PersonAll: Codable {
    var ID_Login: String
    var DisplayName: String
    var ID_Application: String = APP_ID
}

struct PersonAllCatalog: Codable {
    var ID_Login: String
    var Name: String
    var ID_Application: String = APP_ID
}

struct PersonContactAll: Codable {
    var ID_Login: String
    var ID_Person: String
    var ID_Application: String = APP_ID
}

struct PersonDetail: Codable {
    var ID_Login: String
    var ID: String
    var ID_Application: String = APP_ID
}

struct QualificationAll: Codable {
    var ID_Login: String
    var ID_Person: String
    var ID_Application: String = APP_ID
}

struct FunctionAllPerson: Codable {
    var ID_Login: String
    var ID_Person: String
    var ID_Application: String = APP_ID
}

struct MembershipAllPerson: Codable {
    var ID_Login: String
    var ID_Person: String
    var ID_Application: String = APP_ID
}

struct MembershipAll: Codable {
    var ID_Login: String
    var ID_Unit: String
    var ID_Application: String = APP_ID
}

struct OfferAll: Codable {
    var ID_Login: String
    var ID_Person: String
    var ID_Application: String = APP_ID
}

struct PersonPhoto: Codable {
    var ID_Login: String
    var ID: String
    var Size: String
    var ID_Application: String = APP_ID
}

struct UnitDetail: Codable {
    var ID_Login: String
    var ID: String
    var ID_Application: String = APP_ID
}

struct UnitContactAll: Codable {
    var ID_Login: String
    var ID_Unit: String
    var ID_Application: String = APP_ID
}

struct FunctionAll: Codable {
    var ID_Login: String
    var ID_Unit: String
    var ID_Application: String = APP_ID
}

struct UnitTreeAll: Codable {
    var ID_Login: String
    var ID_UnitParent: String
    var ID_Application: String = APP_ID
}

struct UnitRegistrationAll: Codable {
    var ID_Login: String
    var ID_Unit: String
    var ID_Application: String = APP_ID
}

struct LoginUpdateRefresh: Codable {
    var ID: String
}

struct UnitRegistrationMembers: Codable {
    var ID_Login: String
    var ID: String
    var ID_Application: String = APP_ID
}

